//
// AMIS30624 Micro-Stepper (actuator) 
// Arduino Library
//
//
// May 15, 2011 - initial release
// May 19, 2012 - revised types
//
// CC = BY NC SA
// http://embeddedcomputing.weebly.com
//
#define I2C_STEPPER_RELEASE 102

#ifndef I2C_Stepper_h
#define I2C_Stepper_h

// Core library
#if defined(__AVR_ATmega328P__) || defined(__AVR_ATmega2560__) // Arduino specific
#include "WProgram.h"	
#elif defined(__32MX320F128H__) || defined(__32MX795F512L__) // chipKIT specific 
#include "WProgram.h"
#elif defined(__AVR_ATmega644P__) // Wiring specific
#include "Wiring.h"
#elif defined(__MSP430G2452__) || defined(__MSP430G2553__) || defined(__MSP430G2231__) // LaunchPad specific
#include "Energia.h"
#elif defined(MCU_STM32F103RB) || defined(MCU_STM32F103ZE) || defined(MCU_STM32F103CB) || defined(MCU_STM32F103RE) // Maple specific
#include "WProgram.h"	
#endif

class I2C_Stepper
{
public:
    I2C_Stepper(uint8_t n=0); // constructor
    // as per http://www.arduino.cc/cgi-bin/yabb2/YaBB.pl?num=1250997678
    String WhoAmI();
    void begin();
    void getStatus();    // reads Status1 and Status2
    
    boolean testPumpFailure() { return _testPumpFailure; };
    boolean testElectricalDefect() { return _testElectricalDefect; };
    boolean testReferenceReached() { return _testReferenceReached; };
    uint8_t testMotion() { return _testMotion; };
    uint8_t testStop() { return _testStop; };
    boolean testOverCurrent() { return _testOverCurrent; };
    boolean testOverCurrentX() { return _testOverCurrentX; };
    boolean testOverCurrentY() { return _testOverCurrentY; };
    boolean testStepLoss() { return _testStepLoss; };
    boolean testStall() { return _testStall; };
    boolean testThermalShutDown() { return _testThermalShutDown; };
    boolean testThermalWarning() { return _testThermalWarning; };
    boolean testBatteryUnderVoltage() { return _testBatteryUnderVoltage; };
    boolean testDigitalVoltageReset() { return _testDigitalVoltageReset; };
    boolean testError() { return _testError; };
    int16_t actualPosition() { return _actualPosition; };
    int16_t targetPosition() { return _targetPosition; };
    int16_t securePosition() { return _securePosition; };
    String testTemperatureInfo() { return _testTemperatureInfo; };
	
    void setParameters();
    
    void goPosition(int16_t position);  // check with boolean testPositionReached();
    boolean testPositionReached();
    
    void goSecurePosition();
    
    void resetPosition();
    void resetDefault();
    
    void runVelocity();
    void goReference();  // includes   boolean testReferenceReached();
    
    void softStop();
    void hardStop();
    
private:
    int8_t _address;
    
    boolean _testPumpFailure; 
    boolean _testElectricalDefect; 
    boolean _testReferenceReached; 
    uint8_t _testMotion; 
    boolean _testStop;
    boolean _testOverCurrent; 
	boolean _testOverCurrentX; 
	boolean _testOverCurrentY; 
    boolean _testStepLoss; 
    boolean _testStall; 
    boolean _testThermalShutDown; 
    boolean _testThermalWarning; 
    boolean _testBatteryUnderVoltage; 
    boolean _testDigitalVoltageReset; 
    boolean _testError; 
	String _testTemperatureInfo;
    uint8_t _iRun;
    uint8_t _iHold;
    uint8_t _vMin;
    uint8_t _vMax;
    int32_t _actualPosition;
    int32_t _targetPosition;
    int32_t _securePosition;
    
    
    
};

#endif



